# Hank-tastic Password Generator

This Python script generates a password that Hank Preston would be proud of.

Install it with the following command:

```sh
python -m pip install git+https://github.com/xorrkaz/hankify-pw.git
```

All you really need to do is run it:

```bash
$ hankify-pw
YoreAnywhySollyaBoatbill81
```

If you want to use an alternate word list, specify `--word-file PATH`.  If you want a longer or shorter password, specify `--num-words` (the default is 4).  The package ships with a default words file from FreeBSD.
